==> gspiceui_0.9.98.dfsg.orig.tar.gz: gspiceui-0.9.98.dfsg/src/process/PrcNgSpice.hpp <==
//*****************************************************************************
//                               PrcNgSpice.hpp                               *
//                              ----------------                              *
//  Description : This class provides the interface to the NG-Spice circuit   *
//                simulator.                                                  *
//  Started     : 07/05/2004                                                  *
//  Last Update : 04/09/2009                                                  *
//  Copyright   : (C) 2004 by M.S.Waters                                      *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef PRCNGSPICE_HPP
#define PRCNGSPICE_HPP

// System Includes


// wxWindows Includes

#include <wx/wx.h>

// Application Includes

#include "TypeDefs.hpp"
#include "base/PrcSimrBase.hpp"
#include "netlist/SimnGnuCap.hpp"
#include "ngspice/commands/CmdNgSpiceDC.hpp"
#include "ngspice/commands/CmdNgSpiceAC.hpp"
#include "ngspice/commands/CmdNgSpiceTR.hpp"
#include "ngspice/commands/CmdNgSpicePR.hpp"
#include "utility/ConvertType.hpp"

// Local Constant Declarations

#define  NGSPICE_COL_WD  14  // Width of columns of data in the results files

//*****************************************************************************

class PrcNgSpice : public PrcSimrBase
{
  private :

    // Storage for the result file column labels
    wxString  m_osColLbls;

    // Function to match a component to a set of node labels
    bool  bMatchCpnt( SimnNgSpice & roSimn, wxString & rosToNodes );

    // Functions to create the simulator commands
    void  Convert2Nodes( wxArrayString & rosaCpnts, SimnNgSpice & roSimn );

    // Create the WIDTH command
    wxString & rosMakeCmdWIDTH( wxString & rosCmdPR );

    // Format the results file
    bool  bFmtGeneric  ( void );
    bool  bFmtColumnHdr( void );
    bool  bFmtDataLines( void );
    bool  bFmtPhaseData( void ); // ??? (02/02/2006) Not yet implemented

  public :

    PrcNgSpice( void );
   ~PrcNgSpice( );

    // Create the process argument list
    virtual  bool  bMakeArgLst( SimnBase & roSimn );

    // Format the results file
    virtual  bool  bFmtResults( void );
};

//*****************************************************************************

#endif // PRCNGSPICE_HPP

==> gspiceui_1.0.00+dfsg.orig.tar.gz: gspiceui-1.0.00+dfsg/src/process/PrcNgSpice.hpp <==
//*****************************************************************************
//                               PrcNgSpice.hpp                               *
//                              ----------------                              *
//  Description : This class provides the interface to the NG-Spice circuit   *
//                simulator.                                                  *
//  Started     : 07/05/2004                                                  *
//  Last Update : 12/04/2011                                                  *
//  Copyright   : (C) 2004 by M.S.Waters                                      *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef PRCNGSPICE_HPP
#define PRCNGSPICE_HPP

// System Includes


// wxWidgets Includes

#include <wx/wx.h>

// Application Includes

#include "TypeDefs.hpp"
#include "base/PrcSimrBase.hpp"
#include "netlist/SimnGnuCap.hpp"
#include "ngspice/commands/CmdNgSpiceDC.hpp"
#include "ngspice/commands/CmdNgSpiceAC.hpp"
#include "ngspice/commands/CmdNgSpiceTR.hpp"
#include "ngspice/commands/CmdNgSpicePR.hpp"
#include "utility/ConvertType.hpp"

// Local Constant Declarations

#define  NGSPICE_COL_WD  14  // Width of columns of data in the results files

//*****************************************************************************

class PrcNgSpice : public PrcSimrBase
{
  private :

    // Storage for the result file column labels
    wxString  m_osColLbls;

    // Function to match a component to a set of node labels
    bool  bMatchCpnt( SimnNgSpice & roSimn, wxString & rosToNodes );

    // Functions to create the simulator commands
    void  Convert2Nodes( wxArrayString & rosaCpnts, SimnNgSpice & roSimn );

    // Create the WIDTH command
    wxString & rosMakeCmdWIDTH( wxString & rosCmdPR );

    // Format the results file
    bool  bFmtCommon   ( void );
    bool  bFmtColLabels( void );
    bool  bFmtDataLines( void );
    bool  bFmtPhaseData( void ); // ??? (02/02/2006) Not yet implemented

  public :

    PrcNgSpice( void );
   ~PrcNgSpice( );

    // Create the process argument list
    virtual  bool  bMakeArgLst( SimnBase & roSimn );

    // Format the results file
    virtual  bool  bFmtResults( void );
};

//*****************************************************************************

#endif // PRCNGSPICE_HPP
